import { useEffect, useState } from 'react';
import { AuthorizationHandler } from '@graphpolaris/shared/lib/data-access';

interface useIsAuthorizedState {
  userAuthorized: boolean;
  userId?: string;
  sessionId?: string;
}

export function useAuthorization() {
  const [state, setState] = useState<useIsAuthorizedState>({
    userAuthorized: false,
  });
  const authInstance = AuthorizationHandler.instance();

  const authCallback = async () => {
    setState({
      userAuthorized: authInstance.Authorized(),
      userId: authInstance.UserID(),
      sessionId: authInstance.SessionID(),
    });

    // Print the user that is currently logged in
    // const user = await GetUserInfo();
    // console.log(user);
  };

  authInstance.setCallback(authCallback);

  // Attempt to Authorize the user
  const authorize = async () => {
    const authorized = await authInstance.Authorize();
    if (authorized) authCallback();
  };

  useEffect(() => {
    authorize();
  }, []);

  return state;
}
