import { assert, describe, expect, it, test } from "vitest";
import { SchemaFromBackend } from '@graphpolaris/shared/lib/model/backend';
import { SchemaUtils } from '@graphpolaris/shared/lib/schema/schema-utils';
import { MultiGraph } from 'graphology';
import { Attributes } from 'graphology-types';
import {
  movieSchemaRaw,
  northwindSchemaRaw,
  simpleSchemaRaw,
  twitterSchemaRaw,
} from '@graphpolaris/shared/lib/mock-data';

describe('SchemaUsecases', () => {
  test.each([
    { data: simpleSchemaRaw },
    { data: movieSchemaRaw },
    { data: northwindSchemaRaw },
    { data: twitterSchemaRaw },
  ])('parseSchemaFromBackend parsing should work', ({ data }) => {
    // console.log('testinput', input);

    const parsed = SchemaUtils.schemaBackend2Graphology(
      data as SchemaFromBackend
    );
    expect(parsed).toBeDefined();
  });

  it('should export and reimport', () => {
    const parsed = SchemaUtils.schemaBackend2Graphology(
      simpleSchemaRaw as SchemaFromBackend
    );
    const reload = MultiGraph.from(parsed.export());

    expect(parsed).toStrictEqual(reload);
  });

  test.each([
    { data: simpleSchemaRaw },
    { data: movieSchemaRaw },
    { data: northwindSchemaRaw },
    { data: twitterSchemaRaw },
  ])('should load my test json $data', ({ data }) => {
    expect(data).toBeDefined();
    expect(data.nodes).toBeDefined();
  });
});
